@@ -173,7 +173,7 @@ class Deck:
     def draw(self) -> Card:
         """Draw a random card from the draw pile."""
         if len(self._draw_pile) < 1:
-            # this is equivalent to shuffling the discard pile into the draw pile
+            # this is equivalent to shuffling the discard pile into the draw pile, because we draw randomly from the deck
             for card in list(self._discard_pile.values()):
                 self._discard_pile.pop(card.id)
                 self._draw_pile[card.id] = card
@@ -436,10 +436,10 @@ class History:
     # noinspection PyUnresolvedReferences
     @timestamp.default
     def _default_timestamp(self) -> DateTime:
-        return pendulum.now(pendulum.UTC)  # type: ignore[attr-defined]
+        return pendulum.now(pendulum.UTC)  # type: ignore[attr-defined,unused-ignore]
 
     def __str__(self) -> str:
-        time = self.timestamp.to_time_string()  # type: ignore
+        time = self.timestamp.to_time_string()  # type: ignore[no-untyped-call,unused-ignore]
         color = "General" if not self.color else self.color.value
         action = self.action
         return "[%s] %s - %s" % (time, color, action)
