@@ -375,7 +375,7 @@ class TestPosition:
     def test_calculate_position_start(self):
         for color in PlayerColor:
             with pytest.raises(ValueError):
-                BoardRules()._position(color, Position().move_to_home(), 1)
+                BoardRules()._position(color, Position().move_to_start(), 1)
 
     def test_calculate_position_from_safe(self):
         for color in PlayerColor:
@@ -450,7 +450,7 @@ class TestPosition:
         assert BoardRules()._position(PlayerColor.RED, Position().move_to_square(59), 4) == Position().move_to_safe(0)
 
         with pytest.raises(ValueError):
-            assert BoardRules()._position(PlayerColor.RED, Position().move_to_square(2), 7) == Position().move_to_home()
+            BoardRules()._position(PlayerColor.RED, Position().move_to_square(2), 7)
 
         assert BoardRules()._position(PlayerColor.BLUE, Position().move_to_square(16), 2) == Position().move_to_safe(0)
         assert BoardRules()._position(PlayerColor.BLUE, Position().move_to_square(17), 1) == Position().move_to_safe(0)
@@ -458,7 +458,7 @@ class TestPosition:
         assert BoardRules()._position(PlayerColor.BLUE, Position().move_to_square(17), 2) == Position().move_to_safe(1)
         assert BoardRules()._position(PlayerColor.BLUE, Position().move_to_square(17), 6) == Position().move_to_home()
         with pytest.raises(ValueError):
-            assert BoardRules()._position(PlayerColor.BLUE, Position().move_to_square(17), 7) == Position().move_to_home()
+            BoardRules()._position(PlayerColor.BLUE, Position().move_to_square(17), 7)
 
         assert BoardRules()._position(PlayerColor.YELLOW, Position().move_to_square(31), 2) == Position().move_to_safe(0)
         assert BoardRules()._position(PlayerColor.YELLOW, Position().move_to_square(32), 1) == Position().move_to_safe(0)
@@ -466,7 +466,7 @@ class TestPosition:
         assert BoardRules()._position(PlayerColor.YELLOW, Position().move_to_square(32), 2) == Position().move_to_safe(1)
         assert BoardRules()._position(PlayerColor.YELLOW, Position().move_to_square(32), 6) == Position().move_to_home()
         with pytest.raises(ValueError):
-            assert BoardRules()._position(PlayerColor.YELLOW, Position().move_to_square(32), 7) == Position().move_to_home()
+            BoardRules()._position(PlayerColor.YELLOW, Position().move_to_square(32), 7)
 
         assert BoardRules()._position(PlayerColor.GREEN, Position().move_to_square(46), 2) == Position().move_to_safe(0)
         assert BoardRules()._position(PlayerColor.GREEN, Position().move_to_square(47), 1) == Position().move_to_safe(0)
@@ -474,7 +474,7 @@ class TestPosition:
         assert BoardRules()._position(PlayerColor.GREEN, Position().move_to_square(47), 2) == Position().move_to_safe(1)
         assert BoardRules()._position(PlayerColor.GREEN, Position().move_to_square(47), 6) == Position().move_to_home()
         with pytest.raises(ValueError):
-            assert BoardRules()._position(PlayerColor.GREEN, Position().move_to_square(47), 7) == Position().move_to_home()
+            BoardRules()._position(PlayerColor.GREEN, Position().move_to_square(47), 7)
 
 
 def _setup_game():
@@ -573,7 +573,7 @@ class TestLegalMoves:
     def test_construct_legal_moves_card_2(self):
         # No legal moves if no pawn in start, on the board, or in safe
         game = _setup_game()
-        card, pawn, view, moves = _legal_moves(RED, game, 0, "1")
+        card, pawn, view, moves = _legal_moves(RED, game, 0, "2")
         assert moves == []
 
         # Move pawn from start with no conflicts
@@ -822,16 +822,14 @@ class TestLegalMoves:
         game.players[RED].pawns[0].position.move_to_square(5)
         game.players[RED].pawns[1].position.move_to_square(15)
         card, pawn, view, moves = _legal_moves(RED, game, 0, "10")
-        assert moves == [Move(card, actions=[_square(pawn, 4)], side_effects=[])]  # can't move because we have a pawn there already
+        assert moves == [Move(card, actions=[_square(pawn, 4)], side_effects=[])]
 
         # Move pawn on board with conflict (same color)
         game = _setup_game()
         game.players[RED].pawns[0].position.move_to_square(5)
         game.players[RED].pawns[1].position.move_to_square(4)
         card, pawn, view, moves = _legal_moves(RED, game, 0, "10")
-        assert moves == [
-            Move(card, actions=[_square(pawn, 15)], side_effects=[])
-        ]  # can't move because we have a pawn there already
+        assert moves == [Move(card, actions=[_square(pawn, 15)], side_effects=[])]
 
         # Move pawn on board with conflict (different color)
         game = _setup_game()
@@ -891,7 +889,7 @@ class TestLegalMoves:
         game.players[GREEN].pawns[0].position.move_to_start()  # can't be swapped, in start area
         game.players[YELLOW].pawns[0].position.move_to_safe(0)  # can't be swapped, in safe area
         game.players[YELLOW].pawns[3].position.move_to_square(52)  # can be swapped, on board
-        game.players[BLUE].pawns[1].position.move_to_square(19)  # can be swapped, on board\
+        game.players[BLUE].pawns[1].position.move_to_square(19)  # can be swapped, on board
         card, pawn, view, moves = _legal_moves(RED, game, 0, "11")
         assert moves == [
             Move(card, actions=_swap(view, pawn, YELLOW, 3), side_effects=[]),
